@@ -17,7 +17,6 @@ import Codec.Encryption.OpenPGP.CFB (decryptNoNonce, encryptNoNonce)
 import Codec.Encryption.OpenPGP.Serialize (getSecretKey)
 import Codec.Encryption.OpenPGP.S2K (skesk2Key, string2Key)
 import qualified Crypto.Hash as CH
-import qualified Crypto.Hash.Algorithms as CHA
 import Crypto.Random.EntropyPool (createEntropyPool, getEntropyFrom)
 import qualified Data.ByteArray as BA
 import qualified Data.ByteString as B
@@ -28,6 +27,7 @@ import Data.Binary.Put (runPut)
 import Data.Bifunctor (bimap)
 import qualified Crypto.PubKey.RSA as R
 
+saBlockSize :: SymmetricAlgorithm -> Int
 saBlockSize sa = either (const 0) id (withSymmetricCipher sa B.empty (Right . blockSize))
 
 decryptPrivateKey :: (PKPayload, SKAddendum) -> BL.ByteString -> SKAddendum
